@@ -7,7 +7,6 @@ from tabml.config_helpers import parse_pipeline_config
 from tabml.experiment_manager import ExperimentManger
 from tabml.feature_manager import BaseFeatureManager
 from tabml.model_wrappers import initialize_model_wrapper
-from tabml.schemas import pipeline_config
 
 
 @dataclass
@@ -20,8 +19,10 @@ class ModelInference:
 
     def __post_init__(self):
         self._init_feature_manager()
-        config = self._get_config()
-        self._load_model_wrapper(config.model_wrapper)
+        config = _get_config(self.pipeline_config_path, self.model_path)
+        self.model_wrapper = initialize_model_wrapper(
+            config.model_wrapper, self.model_path
+        )
         self.features_to_model = list(config.data_loader.features_to_model)
 
     def _init_feature_manager(self):
@@ -30,17 +31,6 @@ class ModelInference:
         )
         self.fm.load_transformers()
 
-    def _get_config(self):
-        pipeline_config_path = (
-            self.pipeline_config_path
-            or ExperimentManger.get_config_path_from_model_path(self.model_path)
-        )
-        return parse_pipeline_config(pipeline_config_path)
-
-    def _load_model_wrapper(self, model_wrapper_params: pipeline_config.ModelWrapper):
-        self.model_wrapper = initialize_model_wrapper(model_wrapper_params)
-        self.model_wrapper.load_model(self.model_path)
-
     def predict(self, raw_data: List[Dict[str, Any]]) -> Iterable[Any]:
         """Makes prediction for new samples.
 
@@ -50,3 +40,11 @@ class ModelInference:
         """
         features = self.fm.transform_new_samples(raw_data, self.features_to_model)
         return self.model_wrapper.predict(features[self.features_to_model])
+
+
+def _get_config(pipeline_config_path, model_path):
+    pipeline_config_path = (
+        pipeline_config_path
+        or ExperimentManger.get_config_path_from_model_path(model_path)
+    )
+    return parse_pipeline_config(pipeline_config_path)
